@@ -11,18 +11,18 @@ roofEdge <- function(image, bandwidth, thresh, edge1, blur = FALSE,
   n2 <- as.integer(dim(image)[2])
   if (n1 != n2)
     stop("image data must be a square matrix.")
-  if (!is.numeric(bandwidth) | length(bandwidth) > 1)
+  if (!is.numeric(bandwidth) || length(bandwidth) > 1)
     stop("bandwidth must be a positive integer.")
   if (as.integer(bandwidth) < 1)
     stop("bandwidth must be a positive integer.")
 #   if (n1 + 2 * bandwidth + 2 > 600)
 #     stop("bandwidth is too large or the resolution
 # of the image is too high.")
-  if (!is.numeric(thresh) | length(thresh) > 1 | thresh < 0)
+  if (!is.numeric(thresh) || length(thresh) > 1 || thresh < 0)
     stop("threshold  must be a positive number.")
-  if(!is.matrix(edge1) | ncol(edge1) != nrow(edge1))
+  if(!is.matrix(edge1) || ncol(edge1) != nrow(edge1))
     stop("edge1 must be a square matrix")
-  if(!all(edge1==0 | edge1==1))
+  if(!all(edge1 == 0 | edge1 == 1))
     stop("edge1's must be either 0 or 1.")
   if(ncol(edge1) != n1)
     stop("edge1 and image are not of the same size.")
